@@ -33,6 +33,7 @@ class BaseLog:
         self.prefix_path = prefix_path
         self.program_log_name = app_name + '_code'
         self.journal_log_name = app_name + '_info'
+        self.job_log_name = app_name + '_trace'
         self.host_name = socket.gethostname()
         self.generate_loggers(when, backup_count)
         self.journal_log_enable = journal_log_enable
@@ -86,6 +87,15 @@ class BaseLog:
             data.update(extra)
         return json.dumps(data, ensure_ascii=False)
 
+    def trace_model(self, level, extra=None):
+        data = {
+            "app_name": self.job_log_name,  # 服务编号
+            "level": level,
+        }
+        if isinstance(extra, dict):
+            data.update(extra)
+        return json.dumps(data, ensure_ascii=False)
+
     def get_current_location(self):
         try:
             path_name, lineno, func_name = self.find_caller()
@@ -138,6 +148,10 @@ class BaseLog:
         message = self.program_model('ERROR', msg, kwargs.get('extra'))
         logging.getLogger(self.program_log_name).error(message, *args, **kwargs)
 
+    def trace(self, *args, **kwargs):
+        message = self.trace_model('TRACE', kwargs)
+        logging.getLogger(self.job_log_name).debug(message, *args, **kwargs)
+
     def external_log(self,
                      transaction_id,
                      request_url,
